@@ -13,6 +13,9 @@ logging.basicConfig(
     level=logging.INFO,
     datefmt="%c",
 )
+# Mute numexpr threads info
+logging.getLogger("numexpr").setLevel(logging.WARNING)
+
 # Custom functions
 from .utils import rest_query, get_uniprot_info, wrap_cols_func
 
@@ -26,6 +29,7 @@ def info(ens_ids, expand=False, wrap_text=False, json=False, verbose=True, save=
 
     Args:
     - ens_ids       One or more Ensembl IDs to look up (string or list of strings).
+                    Also supports WormBase and Flybase IDs.
     - expand        True/False wether to expand returned information (only for genes and transcripts). Default: False.
                     For genes, this adds transcript isoform information.
                     For transcripts, this adds translation and exon information.
@@ -49,19 +53,27 @@ def info(ens_ids, expand=False, wrap_text=False, json=False, verbose=True, save=
     ens_ids_clean = []
     temp = 0
     for ensembl_ID in ens_ids:
-        ens_ids_clean.append(ensembl_ID.split(".")[0])
+        # But only for Ensembl ID (and not for flybase/wormbase IDs)
+        if ensembl_ID.startswith("ENS"):
+            ens_ids_clean.append(ensembl_ID.split(".")[0])
 
-        if "." in ensembl_ID and temp == 0:
-            if verbose is True:
-                logging.info(
-                    "We noticed that you may have passed a version number with your Ensembl ID.\n"
-                    "Please note that gget info will always return information linked to the latest Ensembl ID version (see 'ensembl_id')."
-                )
-            temp = +1
+            if "." in ensembl_ID and temp == 0:
+                if verbose is True:
+                    logging.info(
+                        "We noticed that you may have passed a version number with your Ensembl ID.\n"
+                        "Please note that gget info will always return information linked to the latest Ensembl ID version (see 'ensembl_id')."
+                    )
+                temp = +1
+
+        else:
+            ens_ids_clean.append(ensembl_ID)
 
     # Initiate dictionary to save results for all IDs in
     master_dict = {}
 
+    # Create second clean list of Ensembl IDs which will not include IDs that were not found
+    ens_ids_clean_2 = ens_ids_clean.copy()
+
     # Query REST APIs from https://rest.ensembl.org/
     for ensembl_ID in ens_ids_clean:
         # Create dict to save query results
@@ -103,10 +115,14 @@ def info(ens_ids, expand=False, wrap_text=False, json=False, verbose=True, save=
 
             # Log error if this also did not work
             except RuntimeError:
-                logging.error(
-                    f"Ensembl ID '{ensembl_ID}' not found. "
+                logging.warning(
+                    f"ID '{ensembl_ID}' not found. "
                     "Please double-check spelling/arguments and try again."
                 )
+
+                # Remove IDs that were not found from ID list
+                ens_ids_clean_2.remove(ensembl_ID)
+
                 continue
 
         # Add results to master dict
@@ -129,47 +145,40 @@ def info(ens_ids, expand=False, wrap_text=False, json=False, verbose=True, save=
         }
     )
 
-    # UniProt version 2022_02 requires the ID to be passed including the version number for homo sapiens
-    # https://www.uniprot.org/news/2022/05/25/release
-    # Collect all IDs with their latest version number
-    uniprot_ens_ids = []
-    for id_ in ens_ids_clean:
-        uniprot_ens_ids.append(master_dict[id_]["ensembl_id"])
-
     ## For genes and transcripts, get gene names and descriptions from UniProt
     df_temp = pd.DataFrame()
-    for ens_id, uniprot_ens_id, id_type in zip(
-        ens_ids_clean, uniprot_ens_ids, df.loc["object_type"].values
-    ):
+    for ens_id, id_type in zip(ens_ids_clean_2, df.loc["object_type"].values):
         if id_type == "Gene" or id_type == "Transcript":
 
             # Check if this is a wrombase ID:
             if ens_id.startswith("WB"):
+                df_uniprot = get_uniprot_info(
+                    UNIPROT_REST_API, ens_id, id_type="WB_Gene", verbose=verbose
+                )
+            elif ens_id.startswith("T"):
+                df_uniprot = get_uniprot_info(
+                    UNIPROT_REST_API,
+                    ".".join(
+                        ens_id.split(".")[:-1]
+                    ),  # Remove the version number from WormBase TRS IDs for submission to UniProt
+                    id_type="WB_Transcript",
+                    verbose=verbose,
+                )
+
+            # Check if this is a flybase ID:
+            elif ens_id.startswith("FB"):
                 if id_type == "Gene":
                     df_uniprot = get_uniprot_info(
-                        UNIPROT_REST_API, ens_id, id_type="WB_Gene", verbose=verbose
+                        UNIPROT_REST_API, ens_id, id_type="FB_Gene", verbose=verbose
                     )
-
                 else:
                     df_uniprot = get_uniprot_info(
                         UNIPROT_REST_API,
                         ens_id,
-                        id_type="WB_Transcript",
+                        id_type="FB_Transcript",
                         verbose=verbose,
                     )
 
-            # Check if this is a flybase ID:
-            elif ens_id.startswith("FB"):
-                df_uniprot = get_uniprot_info(
-                    UNIPROT_REST_API, ens_id, id_type="Flybase", verbose=verbose
-                )
-
-            # Check if this ID requires a version number
-            elif master_dict[ens_id]["species"] == "homo_sapiens":
-                df_uniprot = get_uniprot_info(
-                    UNIPROT_REST_API, uniprot_ens_id, id_type=id_type, verbose=verbose
-                )
-
             else:
                 df_uniprot = get_uniprot_info(
                     UNIPROT_REST_API, ens_id, id_type=id_type, verbose=verbose
@@ -179,18 +188,16 @@ def info(ens_ids, expand=False, wrap_text=False, json=False, verbose=True, save=
                 # If two different UniProt IDs for a single query ID are returned, they should be merged into one column
                 # So len(df_uniprot) should always be 1
                 if len(df_uniprot) > 1:
+                    # If the above somehow failed, we will only return the first result.
                     df_uniprot = df_uniprot.iloc[[0]]
-                    # This should not be necessary
                     if verbose is True:
                         logging.warning(
-                            f"More than one UniProt match was found for Ensembl ID {ens_id}. Only the first match and its associated information will be returned."
+                            f"More than one UniProt match was found for ID {ens_id}. Only the first match and its associated information will be returned."
                         )
 
             else:
                 if verbose is True:
-                    logging.warning(
-                        f"No UniProt entry was found for Ensembl ID {ens_id}."
-                    )
+                    logging.warning(f"No UniProt entry was found for ID {ens_id}.")
 
             ## Get NCBI gene ID and description (for genes only)
             url = NCBI_URL + f"/gene/?term={ens_id}"
