@@ -6,6 +6,9 @@ logging.basicConfig(
     level=logging.INFO,
     datefmt="%c",
 )
+# Mute numexpr threads info
+logging.getLogger("numexpr").setLevel(logging.WARNING)
+
 import numpy as np
 
 # Custom functions
@@ -24,16 +27,17 @@ def seq(
 ):
     """
     Fetch nucleotide or amino acid sequence (FASTA) of a gene
-    (and all its isoforms) or transcript by Ensembl ID.
+    (and all its isoforms) or transcript by Ensembl, WormBase or FlyBase ID.
 
     Args:
     - ens_ids   One or more Ensembl IDs (passed as string or list of strings).
+                Also supports WormBase and FlyBase IDs.
     - seqtype   'gene' (default) or 'transcript'.
                 Defines whether nucleotide or amino acid sequences are returned.
                 Nucleotide sequences are fetched from the Ensembl REST API server.
                 Amino acid sequences are fetched from the UniProt REST API server.
     - isoforms  If True, returns the sequences of all known transcripts (default: False).
-                (Only for gene IDs in combination with seqtype='transcript'.)
+                (Only for gene Ensembl IDs.)
     - save      If True: Save output FASTA to current directory.
 
     Returns a list (or FASTA file if 'save=True') containing the requested sequences.
@@ -54,8 +58,21 @@ def seq(
         ens_ids = [ens_ids]
     # Remove Ensembl ID version if passed
     ens_ids_clean = []
+    temp = 0
     for ensembl_ID in ens_ids:
-        ens_ids_clean.append(ensembl_ID.split(".")[0])
+        # But only for Ensembl ID (and not for flybase/wormbase IDs)
+        if ensembl_ID.startswith("ENS"):
+            ens_ids_clean.append(ensembl_ID.split(".")[0])
+
+            if "." in ensembl_ID and temp == 0:
+                logging.info(
+                    "We noticed that you may have passed a version number with your Ensembl ID.\n"
+                    "Please note that gget seq will return information linked to the latest Ensembl ID version."
+                )
+                temp = +1
+
+        else:
+            ens_ids_clean.append(ensembl_ID)
 
     # Initiate empty 'fasta'
     fasta = []
@@ -100,7 +117,7 @@ def seq(
 
                 except RuntimeError:
                     logging.error(
-                        f"Ensembl ID {ensembl_ID} not found. "
+                        f"ID {ensembl_ID} not found. "
                         "Please double-check spelling/arguments and try again."
                     )
 
@@ -112,7 +129,7 @@ def seq(
                 # Check that Ensembl ID was found
                 if isinstance(info_df, type(None)):
                     logging.error(
-                        f"Ensembl ID {ensembl_ID} not found. "
+                        f"ID {ensembl_ID} not found. "
                         "Please double-check spelling/arguments and try again."
                     )
                     continue
@@ -147,7 +164,7 @@ def seq(
 
                         except RuntimeError:
                             logging.error(
-                                f"Ensembl ID {transcipt_id} not found. "
+                                f"ID {transcipt_id} not found. "
                                 "Please double-check spelling/arguments and try again."
                             )
 
@@ -177,7 +194,7 @@ def seq(
 
                     except RuntimeError:
                         logging.error(
-                            f"Ensembl ID {ensembl_ID} not found. "
+                            f"ID {ensembl_ID} not found. "
                             "Please double-check spelling/arguments and try again."
                         )
 
@@ -212,7 +229,7 @@ def seq(
                 # Check that Ensembl ID was found
                 if isinstance(info_df, type(None)):
                     logging.error(
-                        f"Ensembl ID {ensembl_ID} not found. "
+                        f"ID {ensembl_ID} not found. "
                         "Please double-check spelling/arguments and try again."
                     )
                     continue
@@ -224,24 +241,32 @@ def seq(
                     # Get ID of canonical transcript
                     can_trans = info_df.loc[ensembl_ID]["canonical_transcript"]
 
-                    # UniProt version 2022_02 requires version number for human Ensembl IDs
-                    if info_df.loc[ensembl_ID]["species"] == "homo_sapiens":
-                        trans_ids.append(can_trans)
+                    if ensembl_ID.startswith("ENS"):
+                        temp_trans_id = can_trans.split(".")[0]
+                        # Remove Ensembl ID version from transcript IDs and append to transcript IDs list
+                        trans_ids.append(temp_trans_id)
+
+                    elif ensembl_ID.startswith("WB"):
+                        # Remove added "." at the end of transcript IDs
+                        temp_trans_id1 = ".".join(can_trans.split(".")[:-1])
+                        # For WormBase transcript IDs, also remove the version number for submission to UniProt API
+                        temp_trans_id = ".".join(temp_trans_id1.split(".")[:-1])
+                        trans_ids.append(temp_trans_id)
 
                     else:
-                        # Remove Ensembl ID version from transcript IDs and append to transcript IDs list
-                        trans_ids.append(can_trans.split(".")[0])
+                        # Remove added "." at the end of other transcript IDs
+                        temp_trans_id = ".".join(can_trans.split(".")[:-1])
+                        trans_ids.append(temp_trans_id)
 
                     logging.info(
-                        f"Requesting amino acid sequence of the canonical transcript {can_trans.split('.')[0]} of gene {ensembl_ID} from UniProt."
+                        f"Requesting amino acid sequence of the canonical transcript {temp_trans_id} of gene {ensembl_ID} from UniProt."
                     )
 
                 # If the ID is a transcript, append the ID directly
                 elif ens_ID_type == "Transcript":
-                    # UniProt version 2022_02 requires version number for human Ensembl IDs
-                    if info_df.loc[ensembl_ID]["species"] == "homo_sapiens":
-                        trans_ids.append(info_df.loc[ensembl_ID]["ensembl_id"])
-
+                    # For WormBase transcript IDs, remove the version number for submission to UniProt API
+                    if ensembl_ID.startswith("T"):
+                        trans_ids.append(".".join(ensembl_ID.split(".")[:-1]))
                     else:
                         trans_ids.append(ensembl_ID)
 
@@ -255,7 +280,7 @@ def seq(
                     )
 
             # Check if this is a Wrombase ID:
-            if ensembl_ID.startswith("WB"):
+            if ensembl_ID.startswith("WB") or ensembl_ID.startswith("T"):
                 id_type = "wormbase"
             # Check if this is a flybase ID:
             elif ensembl_ID.startswith("FB"):
@@ -277,7 +302,7 @@ def seq(
                 # Check that Ensembl ID was found
                 if isinstance(info_df, type(None)):
                     logging.error(
-                        f"Ensembl ID {ensembl_ID} not found. "
+                        f"ID {ensembl_ID} not found. "
                         "Please double-check spelling/arguments and try again."
                     )
                     continue
@@ -288,26 +313,25 @@ def seq(
                 if ens_ID_type == "Gene":
                     # Get the IDs of all transcripts from the gget info results
                     for transcipt_id in info_df.loc[ensembl_ID]["all_transcripts"]:
-                        if info_df.loc[ensembl_ID]["species"] == "homo_sapiens":
-                            # UniProt 2022_02 requires version number for human genes
-                            trans_ids.append(
-                                info(transcipt_id, verbose=False)["ensembl_id"].values[
-                                    0
-                                ]
-                            )
-
-                        else:
+                        if ensembl_ID.startswith("ENS"):
                             # Append transcript ID (without Ensembl version number) to list of transcripts to fetch
                             trans_ids.append(transcipt_id.split(".")[0])
 
+                        else:
+                            # Remove added "." at the end of other transcript IDs
+                            # Note: No need to remove the version number for WormBase IDs here, because "all_transcripts" are returned without version numbers
+                            temp_trans_id = ".".join(transcipt_id.split(".")[:-1])
+                            trans_ids.append(temp_trans_id)
+
                     logging.info(
                         f"Requesting amino acid sequences of all transcripts of gene {ensembl_ID} from UniProt."
                     )
 
                 elif ens_ID_type == "Transcript":
-                    # Append transcript ID to list of transcripts to fetch
-                    if info_df.loc[ensembl_ID]["species"] == "homo_sapiens":
-                        trans_ids.append(info_df.loc[ensembl_ID]["ensembl_id"])
+                    # For WormBase transcript IDs, remove the version number for submission to UniProt API
+                    if ensembl_ID.startswith("T"):
+                        trans_ids.append(".".join(ensembl_ID.split(".")[:-1]))
+
                     else:
                         trans_ids.append(ensembl_ID)
 
@@ -321,8 +345,8 @@ def seq(
                         f"{ensembl_ID} not recognized as either a gene or transcript ID. It will not be included in the UniProt query."
                     )
 
-            # Check if this is a Wrombase ID:
-            if ensembl_ID.startswith("WB"):
+            # Check if this is a Wormbase ID:
+            if ensembl_ID.startswith("WB") or ensembl_ID.startswith("T"):
                 id_type = "wormbase"
             # Check if this is a flybase ID:
             elif ensembl_ID.startswith("FB"):
@@ -342,9 +366,7 @@ def seq(
 
         # Check if no results were found
         if len(df_uniprot) < 1:
-            logging.error(
-                "No UniProt amino acid sequences were found for these Ensembl ID(s)."
-            )
+            logging.error("No UniProt amino acid sequences were found for these ID(s).")
 
         else:
             # Build UniProt results FASTA file
