@@ -8,6 +8,9 @@ logging.basicConfig(
     level=logging.INFO,
     datefmt="%c",
 )
+# Mute numexpr threads info
+logging.getLogger("numexpr").setLevel(logging.WARNING)
+
 import os
 import json
 
@@ -221,7 +224,7 @@ def main():
         type=str,
         nargs="+",
         required=True,
-        help="One or more Ensembl IDs.",
+        help="One or more Ensembl IDs (also supports WormBase and FlyBase IDs).",
     )
     parser_info.add_argument(
         "-e",
@@ -263,7 +266,7 @@ def main():
     )
 
     ## gget seq subparser
-    seq_desc = "Fetch nucleotide or amino acid sequence (FASTA) of a gene (and all isoforms) or transcript by Ensembl ID. "
+    seq_desc = "Fetch nucleotide or amino acid sequence (FASTA) of a gene (and all isoforms) or transcript by Ensembl, WormBase or FlyBase ID. "
     parser_seq = parent_subparsers.add_parser(
         "seq", parents=[parent], description=seq_desc, help=seq_desc, add_help=True
     )
@@ -274,7 +277,7 @@ def main():
         type=str,
         nargs="+",
         required=True,
-        help="One or more Ensembl IDs.",
+        help="One or more Ensembl, WormBase or FlyBase IDs.",
     )
     parser_seq.add_argument(
         "-st",
@@ -294,7 +297,7 @@ def main():
         default=False,
         action="store_true",
         required=False,
-        help="Returns sequences of all known transcripts (default: False). (Only for gene IDs in combination with '--seqtype transcript'.)",
+        help="Returns sequences of all known transcripts (default: False). (Only for gene Ensembl IDs.)",
     )
     parser_seq.add_argument(
         "-o",
